improve

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Overview

Ema.Tools - Publishing Reworked Copyright (C) 2026 Team Quadrimus

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Ema.Tools - Publishing Reworked Copyright (C) 2026 Team Quadrimus

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Ema.Tools - Publishing Reworked Copyright (C) 2026 Team Quadrimus

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Ema.Tools - Publishing Reworked Copyright (C) 2026 Team Quadrimus

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Ema.Tools - Publishing Reworked Copyright (C) 2026 Team Quadrimus

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Testing

func Testing(t *testing.T) (*Assert, *Must)

Types

type Assert

type Assert struct {
	// contains filtered or unexported fields
}

func (*Assert) Do

func (a *Assert) Do(f func()) bool

func (*Assert) Equal

func (a *Assert) Equal(expected, actual any) bool

func (*Assert) Error

func (a *Assert) Error(expected string, actual error) bool

func (*Assert) Nil

func (a *Assert) Nil(actual any) bool

func (*Assert) OK

func (a *Assert) OK(actual error) bool

type Must

type Must struct {
	// contains filtered or unexported fields
}

func (*Must) Do

func (a *Must) Do(f func()) bool

func (*Must) Equal

func (a *Must) Equal(expected, actual any) bool

func (*Must) Error

func (a *Must) Error(expected string, actual error) bool

func (*Must) Nil

func (a *Must) Nil(actual any) bool

func (*Must) OK

func (a *Must) OK(actual error) bool

Jump to